@@ -20,7 +20,7 @@ class mangaSearch:
         variables = {
             'search': sQ,
             'page': 1,
-            'perPage': 5,
+            'perPage': 16,
             'MediaType': "MANGA"
         }
 
@@ -32,4 +32,7 @@ class mangaSearch:
     def id(self, resultnumber: int):
         return self.media[resultnumber]["id"]
     def title(self, resultnumber: int):
-        return self.media[resultnumber]["title"]["romaji"]
\ No newline at end of file
+        return self.media[resultnumber]["title"]["romaji"]
+
+    def result(self):
+        return self.media
\ No newline at end of file
